# Trackrefiner: A precision tracking tool for bacillus cell tracking

| | |
| --- | --- |
| Package | [![PyPI Latest Release](https://img.shields.io/pypi/v/trackrefiner)](https://pypi.org/project/TrackRefiner/) [![Conda Latest Release](https://img.shields.io/conda/v/ingalls-lab/trackrefiner)](https://anaconda.org/ingalls-lab/trackrefiner) |
| Meta | [![DOI](https://img.shields.io/badge/DOI-10.1101/2025.02.13.637647-blue.svg)](https://www.biorxiv.org/content/10.1101/2025.02.13.637647v1) [![License - BSD 3-Clause](https://img.shields.io/github/license/ingallslab/trackrefiner)](https://github.com/ingallslab/Trackrefiner/blob/main/LICENSE.md) |


<p align="center">
  <img src="https://github.com/user-attachments/assets/4d8233d0-e699-4c7b-9fc3-6a25920e515f" alt="image" width="30%"/>
</p>

<div align="justify"> 
  
**TrackRefiner** is a post-processing tool specifically designed to refine the tracking outputs of CellProfiler, a widely used image processing tool. It improves tracking accuracy by refining segmentation and tracking outputs, pruning incorrect links, and adding missing ones. TrackRefiner combines traditional tracking methods with machine learning classifiers, requiring minimal user input while leveraging a data-driven approach to optimize results.

The general pipeline of TrackRefiner is illustrated in the following figure:

![image](https://github.com/user-attachments/assets/27ab0b8c-5437-4376-80a9-13c5163ec20e)

The following sections provide more details on:
1.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/Installation-Guide'>Installation Guide</a>
2.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/How-to-Run-TrackRefiner'>How to Run TrackRefiner</a>
3.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/Tutorial'>Tutorial</a>
4.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/Reported-Feature-Explanations'>Reported Feature Explanations</a>
5.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/TrackRefiner-Outputs'>TrackRefiner Outputs</a>
6.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/Visualizing-and-Editing-Bacterial-Tracking'>Visualizing and Editing Bacterial Tracking</a>
7.	<a href='https://github.com/ingallslab/Trackrefiner/wiki/Developers'>Developers</a>

</div>
